Enum vapcore_light::request::CompleteRequest[][src]

All request types, in an answerable state.

Variants

A request for block headers.

A request for a header proof (from a CHT)

A request for a transaction index by hash.

A request for a block’s receipts.

A request for a block body.

A request for a merkle proof of an account.

A request for a merkle proof of contract storage.

A request for contract code.

A request for proof of execution,

A request for an epoch signal.

Implementations

impl CompleteRequest[src]

pub fn kind(&self) -> Kind[src]

Inspect the kind of this response.