Enum vapcore_light::request::Response[][src]

pub enum Response {
    Headers(HeadersResponse),
    HeaderProof(HeaderProofResponse),
    TransactionIndex(TransactionIndexResponse),
    Receipts(ReceiptsResponse),
    Body(BodyResponse),
    Account(AccountResponse),
    Storage(StorageResponse),
    Code(CodeResponse),
    Execution(ExecutionResponse),
    Signal(SignalResponse),
}

All response types.

Variants

A response for block headers.

HeaderProof(HeaderProofResponse)

A response for a header proof (from a CHT)

TransactionIndex(TransactionIndexResponse)

A response for a transaction index.

A response for a block’s receipts.

A response for a block body.

A response for a merkle proof of an account.

A response for a merkle proof of contract storage.

A response for contract code.

A response for proof of execution,

A response for epoch change signal.

Implementations

impl Response[src]

pub fn kind(&self) -> Kind[src]

Inspect the kind of this response.