Struct vapcore_light::request::Builder[][src]

pub struct Builder<T> { /* fields omitted */ }

Build chained requests. Push them onto the series with push, and produce a Batch object with build. Outputs are checked for consistency.

Implementations

impl<T: IncompleteRequest> Builder<T>[src]

pub fn push(&mut self, request: T) -> Result<(), NoSuchOutput>[src]

Attempt to push a request onto the request chain. Fails if the request references a non-existent output of a prior request.

pub fn output_kinds(&self) -> &HashMap<(usize, usize), OutputKind>[src]

Get a reference to the output kinds map.

pub fn build(self) -> Batch<T>[src]

Convert this into a “batch” object.